diff rdt.h @ 4025:4a266106f604 libavformat

Rename variables in ff_rdt_parse_header() and callers to match the comment documentation in that function. See discussion on ML in the "[PATCH] RDT/Realmedia patches #2" thread.
author rbultje
date Sat, 15 Nov 2008 02:22:47 +0000
parents ff78dd8e198a
children 9a0a46d465ae
line wrap: on
line diff
--- a/rdt.h	Fri Nov 14 19:33:22 2008 +0000
+++ b/rdt.h	Sat Nov 15 02:22:47 2008 +0000
@@ -72,14 +72,14 @@
  *
  * @param buf input buffer
  * @param len length of input buffer
  * @param sn will be set to the stream number this packet belongs to
  * @param seq will be set to the sequence number this packet belongs to
  * @param rn will be set to the rule number this packet belongs to
  * @param ts will be set to the timestamp of the packet
  * @return the amount of bytes consumed, or <0 on error
  */
 int ff_rdt_parse_header(const uint8_t *buf, int len,
-                        int *sn, int *seq, int *rn, uint32_t *ts);
+                        int *set_id, int *seq_no, int *stream_id, uint32_t *timestamp);
 
 /**
  * Parse RDT-style packet data (header + media data).
@@ -72,14 +72,14 @@
  * @param buf input buffer
  * @param len length of input buffer
- * @param sn will be set to the stream number this packet belongs to
- * @param seq will be set to the sequence number this packet belongs to
- * @param rn will be set to the rule number this packet belongs to
- * @param ts will be set to the timestamp of the packet
+ * @param set_id will be set to the set ID this packet belongs to
+ * @param seq_no will be set to the sequence number this packet belongs to
+ * @param stream_id will be set to the stream ID this packet belongs to
+ * @param timestamp will be set to the timestamp of the packet
  * @return the amount of bytes consumed, or <0 on error
  */